# Post-quantum encryption contender is taken out by single-core PC and 1 hour
## Leave it to mathematicians to muck up what looked like an impressive new algorithm.
## Information:

+ Link: https://arstechnica.com/information-technology/2022/08/sike-once-a-post-quantum-encryption-contender-is-koed-in-nist-smackdown/
+ Source: Ars Technica
+ Author: Dan Goodin
+ Date published: 02 August 2022, 12:31
+ Date scraped: 02 August 2022, 13:02

## Article:
![Main article image](https://cdn.arstechnica.net/wp-content/uploads/2022/08/quantum-computing2-760x380.jpeg)







In the US government's ongoing campaign to protect data in the age of quantum computers, a new and powerful attack that used a single traditional computer to completely break a fourth-round candidate highlights the risks involved in standardizing the next generation of encryption algorithms.


Last month, the US Department of Commerce's National Institute of Standards and Technology, or NIST, selected [four post-quantum computing encryption algorithms](https://arstechnica.com/information-technology/2022/07/nist-selects-quantum-proof-algorithms-to-head-off-the-coming-cryptopocalypse/) to replace algorithms like RSA, Diffie-Hellman, and elliptic curve Diffie-Hellman, which are unable to withstand attacks from a quantum computer.
In the same move, NIST advanced four additional algorithms as potential replacements pending further testing in hopes one or more of them may also be suitable encryption alternatives in a post-quantum world. The new attack breaks SIKE, which is one of the latter four additional algorithms. The attack has no impact on the four PQC algorithms selected by NIST as approved standards, all of which rely on completely different mathematical techniques than SIKE.


## Getting totally SIKEd


SIKE—short for [Supersingular Isogeny Key Encapsulation](https://sike.org/)—is now likely out of the running thanks to research that was published over the weekend by researchers from the [Computer Security and Industrial Cryptography](https://www.esat.kuleuven.be/cosic/) group at KU Leuven. The paper, titled [An Efficient Key Recovery Attack on SIDH (Preliminary Version)](https://eprint.iacr.org/2022/975.pdf), described a technique that uses complex mathematics and a single traditional PC to recover the encryption keys protecting the SIKE-protected transactions. The entire process requires only about an hour’s time.


“The newly uncovered weakness is clearly a major blow to SIKE,” David Jao, a professor at the University of Waterloo and co-inventor of SIKE, wrote in an email. “The attack is really unexpected.”


The advent of public key encryption in the 1970s was a major breakthrough because it allowed parties who had never met to securely trade encrypted material that couldn’t be broken by an adversary. Public key encryption relies on asymmetric keys, with one private key used to decrypt messages and a separate public key for encrypting. Users make their public key widely available. As long as their private key remains secret, the scheme remains secure.


In practice, public key cryptography can often be unwieldy, so many systems rely on key encapsulation mechanisms, which allow parties who have never met before to jointly agree on a symmetric key over a public medium such as the Internet. In contrast to symmetric-key algorithms, key encapsulation mechanisms in use today are easily broken by quantum computers. SIKE, before the new attack, was thought to avoid such vulnerabilities by using a complex mathematical construction known as a supersingular isogeny graph.


The cornerstone of SIKE is a protocol called SIDH, short for Supersingular Isogeny Diffie-Hellman. The research paper published over the weekend shows how SIDH is vulnerable to a theorem known as “glue-and-split” developed by mathematician Ernst Kani in 1997, as well as tools devised by fellow mathematicians Everett W. Howe, Franck Lepr´evost, and Bjorn Poonen in 2000. The new technique builds on what’s known as the “GPST adaptive attack,” described in a [2016 paper](https://eprint.iacr.org/2016/859.pdf). The math behind the latest attack is guaranteed to be impenetrable to most non-mathematicians. Here’s about as close as you’re going to get:


“The attack exploits the fact that SIDH has auxiliary points and that the degree of the secret isogeny is known,” [Steven Galbraith](http://www.math.auckland.ac.nz/Directory/profile.php?upi=sgal018), a University of Auckland mathematics professor and the “G” in the GPST adaptive attack, explained in a [short writeup](https://ellipticnews.wordpress.com/2022/07/31/breaking-supersingular-isogeny-diffie-hellman-sidh/) on the new attack. “The auxiliary points in SIDH have always been an annoyance and a potential weakness, and they have been exploited for fault attacks, the GPST adaptive attack, torsion point attacks, etc.


He continued:



> Let ![E_0](https://s0.wp.com/latex.php?latex=E_0&bg=ffffff&fg=333333&s=0&c=20201002) be the base curve and let ![P_0, Q_0 \in E_0](https://s0.wp.com/latex.php?latex=P_0%2C+Q_0+%5Cin+E_0&bg=ffffff&fg=333333&s=0&c=20201002) have order ![2^a](https://s0.wp.com/latex.php?latex=2%5Ea&bg=ffffff&fg=333333&s=0&c=20201002). Let ![E, P, Q](https://s0.wp.com/latex.php?latex=E%2C+P%2C+Q&bg=ffffff&fg=333333&s=0&c=20201002) be given such that there exists an isogeny ![\phi](https://s0.wp.com/latex.php?latex=%5Cphi&bg=ffffff&fg=333333&s=0&c=20201002) of degree ![3^b](https://s0.wp.com/latex.php?latex=3%5Eb&bg=ffffff&fg=333333&s=0&c=20201002) with ![\phi : E_0 \to E](https://s0.wp.com/latex.php?latex=%5Cphi+%3A+E_0+%5Cto+E&bg=ffffff&fg=333333&s=0&c=20201002), ![\phi(P_0) = P](https://s0.wp.com/latex.php?latex=%5Cphi%28P_0%29+%3D+P&bg=ffffff&fg=333333&s=0&c=20201002), and ![\phi(Q_0) = Q.](https://s0.wp.com/latex.php?latex=%5Cphi%28Q_0%29+%3D+Q.&bg=ffffff&fg=333333&s=0&c=20201002)
> 
> 
> A key aspect of SIDH is that one does not compute ![\phi](https://s0.wp.com/latex.php?latex=%5Cphi&bg=ffffff&fg=333333&s=0&c=20201002) directly, but as a composition of isogenies of degree 3. In other words, there is a sequence of curves ![E_0 \to E_1 \to E_2 \to \cdots \to E](https://s0.wp.com/latex.php?latex=E_0+%5Cto+E_1+%5Cto+E_2+%5Cto+%5Ccdots+%5Cto+E&bg=ffffff&fg=333333&s=0&c=20201002) connected by 3-isogenies.
> 
> 
> Essentially, like in GPST, the attack determines the intermediate curves ![E_i](https://s0.wp.com/latex.php?latex=E_i&bg=ffffff&fg=333333&s=0&c=20201002) and hence eventually determines the private key. At step ![i](https://s0.wp.com/latex.php?latex=i&bg=ffffff&fg=333333&s=0&c=20201002) the attack does a brute-force search of all possible ![E_i \to E_{i+1}](https://s0.wp.com/latex.php?latex=E_i+%5Cto+E_%7Bi%2B1%7D&bg=ffffff&fg=333333&s=0&c=20201002), and the magic ingredient is a gadget that shows which one is correct.
> 
> 
> (The above is over-simplified, the isogenies ![E_i \to E_{i+1}](https://s0.wp.com/latex.php?latex=E_i+%5Cto+E_%7Bi%2B1%7D&bg=ffffff&fg=333333&s=0&c=20201002) in the attack are not of degree 3 but of degree a small power of 3.)
> 
> 


More important than understanding the math, Jonathan Katz, an IEEE Member and professor in the department of computer science at the University of Maryland, wrote in an email: “the attack is entirely classical, and does not require quantum computers at all.”







## Lessons learned


SIKE is the second NIST-designated PQC candidate to be invalidated this year. In February, IBM post-doc researcher Ward Beullens published research that [broke Rainbow](https://eprint.iacr.org/2022/214.pdf), a cryptographic signature scheme with its security, according to [Cryptomathic](https://www.cryptomathic.com/news-events/blog/nist-pqc-finalists-update-its-over-for-the-rainbow), “relying on the hardness of the problem of solving a large system of multivariate quadratic equations over a finite field.”


NIST’s PQC replacement campaign has been running for five years. Here’s a brief history:


* [1st round (2017)](https://csrc.nist.gov/Projects/post-quantum-cryptography/post-quantum-cryptography-standardization/Round-1-Submissions)—69 candidates
* [2nd round (2019)](https://csrc.nist.gov/Projects/post-quantum-cryptography/post-quantum-cryptography-standardization/round-2-submissions) - 26 surviving candidates
* [3rd round (2020)](https://csrc.nist.gov/Projects/post-quantum-cryptography/post-quantum-cryptography-standardization/round-3-submissions) - 7 finalists, 8 alternates
* [4th round (2022)](link)- 3 finalists and 1 alternate selected as standards. SIKE and three additional alternates advanced to a 4th round.


Rainbow fell during Round 3. SIKE had made it until Round 4.


Katz continued:



> It is perhaps a bit concerning that this is the second example in the past six months of a scheme that made it to the 3rd round of the NIST review process before being completely broken using a classical algorithm. (The earlier example was Rainbow, which was broken in February.) Three of the four PQC schemes rely on relatively new assumptions whose exact difficulty is not well understood, so what the latest attack indicates is that we perhaps still need to be cautious/conservative with the standardization process going forward.
> 
> 


I asked Jao, the SIKE co-inventor, why the weakness had come to light only now, in a relatively later stage of its development. His answer was insightful. He said:



> It's true that the attack uses mathematics which was published in the 1990s and 2000s. In a sense, the attack doesn't require new mathematics; it could have been noticed at any time. One unexpected facet of the attack is that it uses genus 2 curves to attack elliptic curves (which are genus 1 curves). A connection between the two types of curves is quite unexpected. To give an example illustrating what I mean, for decades people have been trying to attack regular elliptic curve cryptography, including some who have tried using approaches based on genus 2 curves. None of these attempts has succeeded. So for this attempt to succeed in the realm of isogenies is an unexpected development.
> 
> 
> In general there is a lot of deep mathematics which has been published in the mathematical literature but which is not well understood by cryptographers. I lump myself into the category of those many researchers who work in cryptography but do not understand as much mathematics as we really should. So sometimes all it takes is someone who recognizes the applicability of existing theoretical math to these new cryptosystems. That is what happened here.
> 
> 


The version of SIKE submitted to NIST used a single step to generate the key. A possible variant of SIKE could be constructed to take two steps. Jao said that it’s possible that this latter variant might not be susceptible to the math causing this breakage. For now, though, SIKE is dead, at least in the current running. The schedule for the remaining three candidates is currently unknown.












## Tags:


### Autogenerated tags:
[[sidh]] [[pqc]] [[gpst]] [[diffie-hellman]] [[jao]]
