# Single-Core CPU Cracked Post-Quantum Encryption Candidate Algorithm in Just an Hour
## It took researchers about 62 minutes to crack a late-stage Post-Quantum Encryption candidate algorithm using a single-core CPU.
## Information:

+ Link: https://thehackernews.com/2022/08/single-core-cpu-cracked-post-quantum.html
+ Source: The Hacker News
+ Author: Ravie Lakshmanan
+ Date published: 03 August 2022, 16:09
+ Date scraped: 03 August 2022, 17:00

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEguubJspXqDShOQTf_F6etmsP6cL65FpPQ2QOAMeLK7Ie9884UirHJJzHdad66RpCopStrITii9QN5YWmLMLc8UHk-yKSFnfT4Me8HEDtyKhMeYAntSFLIj0dnmKSV-PDXIoxPNtMTqbDLk_dbnY0MGTboXY7BPX4MnhldLHMpONOS2FVPxAmSo1REu/s728-e1000/encryption.jpg)


A late-stage candidate encryption algorithm that was meant to withstand decryption by powerful quantum computers in the future has been trivially cracked by using a computer running Intel Xeon CPU in an hour's time.


The algorithm in question is SIKE — short for Supersingular Isogeny Key Encapsulation — which made it to the [fourth round](https://csrc.nist.gov/Projects/post-quantum-cryptography/round-4-submissions) of the Post-Quantum Cryptography (PQC) standardization process by the U.S. Department of Commerce's National Institute of Standards and Technology (NIST).


"Ran on a single core, the appended [Magma](https://en.wikipedia.org/wiki/Magma_(computer_algebra_system)) [code](https://homes.esat.kuleuven.be/~wcastryc/) breaks the Microsoft [SIKE challenges](https://www.microsoft.com/en-us/msrc/sike-cryptographic-challenge) $IKEp182 and $IKEp217 in about 4 minutes and 6 minutes, respectively," KU Leuven researchers Wouter Castryck and Thomas Decru [said](https://eprint.iacr.org/2022/975) in a new paper.


"A run on the SIKEp434 parameters, previously believed to meet NIST's quantum security level 1, took about 62 minutes, again on a single core."


The code was executed on an Intel [Xeon CPU E5-2630v2](https://en.wikipedia.org/wiki/List_of_Intel_Xeon_processors_(Ivy_Bridge-based)#Xeon_E5-26xx_v2_(dual-processor)) at 2.60GHz, which was released in 2013 using the chip maker's Ivy Bridge microarchitecture, the academics further noted.


The findings come as NIST, in early July, [announced](https://thehackernews.com/2022/07/nist-announces-first-four-quantum.html) the first set of quantum-resistant encryption algorithms: CRYSTALS-Kyber for general encryption, and CRYSTALS-Dilithium, FALCON, and SPHINCS+ for digital signatures.


"SIKE is an [isogeny](https://en.wikipedia.org/wiki/Isogeny)-based key encapsulation suite based on pseudo-random walks in supersingular isogeny graphs," the description from the algorithm authors [reads](https://sike.org/).


Microsoft, which is one of the key collaborators on the algorithm, said SIKE [uses](https://www.microsoft.com/en-us/research/project/sike/) "arithmetic operations on [elliptic curves](https://en.wikipedia.org/wiki/Elliptic-curve_cryptography) defined over finite fields and compute maps, so-called isogenies, between such curves."


"The security of SIDH and SIKE relies on the hardness of finding a specific isogeny between two such elliptic curves, or equivalently, of finding a path between them in the isogeny graph," the tech giant's research team explains.


Quantum-resistant cryptography is an attempt to develop encryption systems that are secure against both quantum and traditional computing systems, while also interoperating with existing communications protocols and networks.


The idea is to ensure that data encrypted today using current algorithms such as [RSA](https://en.wikipedia.org/wiki/RSA_(cryptosystem)), elliptic curve cryptography ([ECC](https://en.wikipedia.org/wiki/Elliptic-curve_cryptography)), [AES](https://en.wikipedia.org/wiki/Advanced_Encryption_Standard), and [ChaCha20](https://en.wikipedia.org/wiki/Salsa20) is not rendered vulnerable to brute-force attacks in the future with the advent of quantum computers.


"Each of these systems relies on some sort of math problem which is easy to do in one direction but hard in the reverse," David Jao, one of the co-inventors of SIKE, told The Hacker News. "Quantum computers can easily solve the hard problems underlying RSA and ECC, which would affect approximately 100% of encrypted internet traffic if quantum computers were to be built."


While SIKE was positioned as one of the NIST-designated PQC contenders, the latest research effectively invalidates the algorithm.


"The work by Castryck and Decru [breaks SIKE](https://ellipticnews.wordpress.com/2022/07/31/breaking-supersingular-isogeny-diffie-hellman-sidh)," Jao said. "Specifically, it breaks [SIDH](https://en.wikipedia.org/wiki/Supersingular_isogeny_key_exchange) [Supersingular Isogeny Diffie-Hellman], the 'hard' problem on which SIKE is based (analogous to how integer factorization is the hard problem on which RSA is based)."


"There are other isogeny-based cryptosystems other than SIKE. Some of these, such as [B-SIDH](https://eprint.iacr.org/2019/1145), are also based on SIDH, and are also broken by the new attack. Some of them, such as [CSIDH](https://csidh.isogeny.org/) and [SQIsign](https://eprint.iacr.org/2020/1240), are not based on SIDH, and as far as we know, are not directly affected by the new attack."


As for the next steps, Jao said while SIDH can be updated to remediate the new line of the key recovery attack, it's expected to be put off until further examination.


"It is possible that SIDH can be patched or fixed up to avoid the new attack, and we have some ideas for how to do so, but more analysis of the new attack is required before we can confidently make a statement about any possible fixes," Jao noted.


  





## Tags:
***email-adresses***: cpue5-2630v2@2.60ghz

### Autogenerated tags:
[[sidh]] [[jao]] [[rsa]]
