# OpenSSL Fixes Multiple New Security Flaws with Latest Update
## OpenSSL project releases patches for multiple security flaws, including a high-severity vulnerability in the widely used encryption toolkit.
## Information:

+ Link: https://thehackernews.com/2023/02/openssl-fixes-multiple-new-security.html
+ Source: The Hacker News
+ Author: Ravie Lakshmanan
+ Date published: 09 February 2023, 09:51
+ Date scraped: 09 February 2023, 10:00

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEj2fd3OTmnadHxr-Z0uIYZhV_g6gmsKQIOAMfSKda0cfz_humOSvXRV2tgMqZOZwJdXm5Z-O6hlN9DktL8VPkAv3yMtCjJJVTOkXWLuwojB8MPvVuRUlhYeQORQ8amKIrPYKlYgjiXA7c_Zt_lNvnymOgbCTv_gxBZiNDfxkOtls3IuJUTVa3ZJwahK/s728-e3650/openssl.png)


The OpenSSL Project has released fixes to address several security flaws, including a high-severity bug in the open source encryption toolkit that could potentially expose users to malicious attacks.


Tracked as [**CVE-2023-0286**](https://nvd.nist.gov/vuln/detail/CVE-2023-0286), the issue relates to a case of type confusion that may permit an adversary to "read memory contents or enact a denial-of-service," the maintainers said in an advisory.


The vulnerability is rooted in the way the [popular cryptographic library](https://thehackernews.com/2022/11/just-in-openssl-releases-patch-for-2.html) handles X.509 certificates, and is likely to impact only those applications that have a custom implementation for retrieving a certificate revocation list ([CRL](https://en.wikipedia.org/wiki/Certificate_revocation_list)) over a network.


"In most cases, the attack requires the attacker to provide both the certificate chain and CRL, neither of which need to have a valid signature," OpenSSL [said](https://www.openssl.org/news/vulnerabilities.html). "If the attacker only controls one of these inputs, the other input must already contain an X.400 address as a CRL distribution point, which is uncommon."


Type confusion flaws could have [serious consequences](https://cwe.mitre.org/data/definitions/843.html), as they could be weaponized to deliberately force the program to behave in unintended ways, possibly causing a crash or code execution.


The issue has been patched in OpenSSL versions 3.0.8, 1.1.1t, and 1.0.2zg. Other security flaws [addressed](https://www.openssl.org/news/secadv/20230207.txt) as part of the latest updates include:


* **CVE-2022-4203** - X.509 Name Constraints Read Buffer Overflow
* **CVE-2022-4304** - Timing Oracle in RSA Decryption
* **CVE-2022-4450** - Double free after calling PEM\_read\_bio\_ex
* **CVE-2023-0215** - Use-after-free following BIO\_new\_NDEF
* **CVE-2023-0216** - Invalid pointer dereference in d2i\_PKCS7 functions
* **CVE-2023-0217** - NULL dereference validating DSA public key
* **CVE-2023-0401** - NULL dereference during PKCS7 data verification

 Successful exploitation of the above shortcomings could lead to an application crash, disclose memory contents, and even recover plaintext messages sent over a network by taking advantage of a [timing-based side-channel](https://nakedsecurity.sophos.com/2023/02/08/openssl-fixes-high-severity-data-stealing-bug-patch-now/) in what's a [Bleichenbacher-style attack](https://thehackernews.com/2022/06/researchers-uncover-ways-to-break.html).


The fixes arrive nearly two months after OpenSSL plugged a low-severity flaw ([CVE-2022-3996](https://nvd.nist.gov/vuln/detail/CVE-2022-3996)) that arises when processing an X.509 certificate, resulting in a denial-of-service condition.



  





## Tags:
***CVE's***: CVE-2022-4304 CVE-2022-3996 CVE-2023-0216 CVE-2023-0217 CVE-2023-0401 CVE-2022-4203 CVE-2023-0215 CVE-2023-0286 CVE-2022-4450

### Autogenerated tags:
[[openssl]] [[x.509]]
