# ÆPIC and SQUIP Vulnerabilities Found in Intel and AMD Processors
## Researchers have uncovered details of the ÆPIC and SQUIP vulnerabilities in Intel and AMD processors that allow attackers to obtain secret info.
## Information:

+ Link: https://thehackernews.com/2022/08/pic-and-squip-vulnerabilities-found-in.html
+ Source: The Hacker News
+ Author: Ravie Lakshmanan
+ Date published: 16 August 2022, 14:58
+ Date scraped: 16 August 2022, 15:02

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEiFc-L8bTWTnQ8C1FBz6T2zdooUgoKYi3VXIGWm1Ls-4uyKHdG7UDxd2fN-juo4cOIf3-J6QOEOEvO-4BXCPnEpAw49p9B9ENgyOr6uJ-tsCCimx5Zdplal-60DulSJAeb587dXc9y1jiNH18gI67Cn8LosAXjs_p8BtX5o_OUsnLMKjgeES0FJ3AUG/s728-e1000/leak.jpg)


A group of researchers has revealed details of a new vulnerability affecting Intel CPUs that enables attackers to obtain encryption keys and other secret information from the processors.


Dubbed [ÆPIC Leak](https://aepicleak.com/), the weakness is the first-of-its-kind to architecturally disclose sensitive data in a manner that's akin to an "uninitialized memory read in the CPU itself."


"In contrast to transient execution attacks like [Meltdown and Spectre](https://thehackernews.com/2022/07/new-retbleed-speculative-execution.html), [ÆPIC Leak](https://github.com/IAIK/AEPIC) is an architectural bug: the sensitive data gets directly disclosed without relying on any (noisy) side channel," the academics said.


The study was conducted by researchers from the Sapienza University of Rome, the Graz University of Technology, Amazon Web Services, and the CISPA Helmholtz Center for Information Security.


The vulnerability ([CVE-2022-21233](https://www.intel.com/content/www/us/en/security-center/advisory/intel-sa-00657.html), CVSS score: 6.0), which affects CPUs with Sunny Cover microarchitecture, is rooted in a component called Advanced Programmable Interrupt Controller ([APIC](https://en.wikipedia.org/wiki/Advanced_Programmable_Interrupt_Controller)), which provides a mechanism to handle and route hardware [interrupt signals](https://en.wikipedia.org/wiki/Interrupt) in a scalable manner.


"The scan of the I/O address space on Intel CPUs based on the Sunny Cove microarchitecture revealed that the memory-mapped registers of the local Advanced Programmable Interrupt Controller (APIC) are not properly initialized," the researchers noted.


"As a result, architecturally reading these registers returns stale data from the microarchitecture. Any data transferred between the L2 and the last-level cache can be read via these registers."


ÆPIC Leak specifically targets systems using Intel's trusted execution environment (TEE) known as Software Guard eXtensions ([SGX](https://thehackernews.com/2021/10/researchers-break-intel-sgx-with-new.html)), causing the leakage of AES and RSA keys from secure enclaves that run on the same physical CPU core with a success rate of 94% and 74% respectively.


[![Intel and AMD Processors](https://thehackernews.com/images/-XX3zQ24zBlk/YvuvMBa6LxI/AAAAAAAAHjw/NKm4QTUxOtEHyp3IVaFry5thVLhN_ntwwCNcBGAsYHQ/s728-e1000/HACKING.jpg)](https://thehackernews.com/images/-XX3zQ24zBlk/YvuvMBa6LxI/AAAAAAAAHjw/NKm4QTUxOtEHyp3IVaFry5thVLhN_ntwwCNcBGAsYHQ/s0/HACKING.jpg)
"By protecting selected code and data from modification, developers can partition their application into hardened enclaves or trusted execution modules to help increase application security," Intel [explains](https://www.intel.com/content/www/us/en/developer/tools/software-guard-extensions/overview.html) about the security assurances offered by SGX.


The flaw, put simply, breaks the aforementioned guarantees, enabling an attacker with permissions to execute privileged native code on a target machine to extract the private keys, and worse defeat attestation, a cornerstone of the security primitives used in SGX to ensure the integrity of code and data.


In response to the findings, Intel has released firmware updates, while describing the issue as a medium-severity vulnerability related to improper isolation of shared resources, leading to information disclosure via local access.


It's also worth noting that Intel has since [deprecated](https://www.intel.com/content/www/us/en/support/articles/000089326/software/intel-security-products.html) support for SGX for its client CPUs, what with a litany of attack methods plaguing the technology, including [SGX-ROP](https://arxiv.org/abs/1902.03256), [MicroScope](https://www.cs.cmu.edu/~dskarlat/publications/microScope_isca19.pdf), [Plundervolt](https://plundervolt.com/), [Load Value Injection](https://lviattack.eu/), [SGAxe](https://thehackernews.com/2020/06/intel-sgaxe-crosstalk-attacks.html), and [VoltPillager](https://zt-chen.github.io/voltpillager/).

## SQUIP Side Channel Attack Affect AMD CPUs

The development comes as researchers demonstrated what's the first-ever side channel attack (CVE-2021-46778) on scheduler queues impacting AMD Zen 1, Zen 2, and Zen 3 microarchitectures that could be abused by an adversary to recover RSA keys.


The attack, codenamed [SQUIP](https://stefangast.eu/papers/squip.pdf) (short for Scheduler Queue Usage via Interference Probing), entails measuring the contention level on scheduler queues to potentially glean sensitive information.


No security updates have been released to patch the line of attack, but the chipmaker has [recommended](https://www.amd.com/en/corporate/product-security/bulletin/amd-sb-1039) that "software developers employ existing best practices, including constant-time algorithms and avoiding secret-dependent control flows where appropriate."


  





## Tags:
***CVE's***: CVE-2022-21233 CVE-2021-46778

### Autogenerated tags:
[[sgx]] [[æpic]]
